@@ -233,13 +233,6 @@ void ApplicationUpdates::transactionFinished(QApt::ExitStatus )
 }
 
 
-bool ApplicationUpdates::isAllMarked() const
-{
-    QApt::PackageList upgradeable = m_aptBackend->upgradeablePackages();
-    int markedCount = m_aptBackend->packageCount(QApt::Package::ToUpgrade);
-    return markedCount >= upgradeable.count();
-}
-
 QDateTime ApplicationUpdates::lastUpdate() const
 {
     return m_aptBackend->timeCacheLastUpdated();
