@@ -59,14 +59,13 @@ class PackageKitResource : public AbstractResource
         QString availablePackageId() const;
 
         QMap<PackageKit::Transaction::Info, QStringList> packages() const { return m_packages; }
-        void setPackages(const QMap<PackageKit::Transaction::Info, QStringList> &packages);
 
         PackageKitBackend* backend() const;
 
         static QString joinPackages(const QStringList& pkgids);
 
     public Q_SLOTS:
-        void addPackageId(PackageKit::Transaction::Info info, const QString &packageId);
+        void addPackageId(PackageKit::Transaction::Info info, const QString &packageId, bool arch);
         void setDetails(const PackageKit::Details& details);
 
         void updateDetail(const QString &packageID,
